'use strict';

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDefaultRenderRoot = exports.createRenderHandler = exports.defaultMapAssets = exports.defaultMapState = undefined;

var _server = require('react-dom/server');

var _render = require('http-middleware-metalab/middleware/render');

var _render2 = _interopRequireDefault(_render);

var _createWait = require('redux-promise-wait/create-wait');

var _createWait2 = _interopRequireDefault(_createWait);

var _htmlescape = require('htmlescape');

var _htmlescape2 = _interopRequireDefault(_htmlescape);

var _createRender = require('./create-render');

var _createRender2 = _interopRequireDefault(_createRender);

var _doctype = require('./doctype');

var _doctype2 = _interopRequireDefault(_doctype);

var _page = require('./component/page');

var _page2 = _interopRequireDefault(_page);

var _action = require('./action');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var CSS_FILE = /\.css$/;
var JS_FILE = /\.js$/;

var renderPage = (0, _doctype2.default)(_createRender2.default)(_server.renderToStaticMarkup, _page2.default);

var defaultMapState = exports.defaultMapState = function defaultMapState(state) /* req */{
  var _state$render = state.render;
  var status = _state$render.status;
  var title = _state$render.title;
  var path = _state$render.path;
  var locale = _state$render.locale;

  return {
    status: status,
    title: title,
    path: path,
    locale: locale
  };
};

var defaultMapAssets = exports.defaultMapAssets = function defaultMapAssets(state, req) {
  var assets = req.assets;

  var styles = assets.filter(function (_ref) {
    var name = _ref.name;
    return CSS_FILE.test(name);
  });
  var scripts = assets.filter(function (_ref2) {
    var name = _ref2.name;
    return JS_FILE.test(name);
  });

  return {
    styles: styles,
    scripts: [{
      id: 'state',
      type: 'text/json',
      content: (0, _htmlescape2.default)(state)
    }].concat(_toConsumableArray(scripts))
  };
};

var createRenderHandler = exports.createRenderHandler = function createRenderHandler(_ref3) {
  var _ref3$mapState = _ref3.mapState;
  var mapState = _ref3$mapState === undefined ? defaultMapState : _ref3$mapState;
  var _ref3$mapAssets = _ref3.mapAssets;
  var mapAssets = _ref3$mapAssets === undefined ? defaultMapAssets : _ref3$mapAssets;
  var renderRoot = _ref3.renderRoot;
  var wait = _ref3.wait;
  return function (req, res, store) {
    var renderRootAsync = (0, _createWait2.default)(renderRoot, store, wait);

    var sendResponse = function sendResponse(markup) {
      var state = store.getState();

      var stateProps = mapState(state, req);
      var assetProps = mapAssets(state, req);
      var pageMarkup = renderPage(_extends({}, stateProps, assetProps, { markup: markup }));

      return {
        markup: pageMarkup,
        assets: assetProps,
        state: stateProps
      };
    };

    return renderRootAsync({ store: store }).then(sendResponse);
  };
};

var createDefaultRenderRoot = exports.createDefaultRenderRoot = function createDefaultRenderRoot(staticRender, rootComponent) {
  return (0, _createRender2.default)(staticRender ? _server.renderToStaticMarkup : _server.renderToString, rootComponent);
};

/**
 * Create render middleware.
 *
 * @function
 *
 * @argument {Object} options An options object.
 *
 * @param {Component} options.rootComponent Your root app component. Receives
 * the Redux store as as a prop when rendered.
 *
 * @param {Function} options.createStore Return a new Redux store.
 *
 * @param {Function=} options.renderRoot Use this instead of
 * `options.rootComponent` if your app has a more complicated entry point.
 * Receives the Redux store as a  arguments and returns a string of markup.
 *
 * @param {Function=} options.mapState Returns an object with the shape
 * `{ status, title, path, locale }`.
 *
 * @param {Function=} options.mapAssets Receives the Redux state and the request
 * object as arguments returns an object with the shape
 * `{ styles[], scripts[] }`.
 *
 * @param {Bool=} options.staticRender Use `reactDOM.renderToStaticMarkup` when
 * rendering `options.rootComponent`. Has no effect if `options.renderRoot` is
 * specified.
 *
 * @param {Object=} options.wait Pass configuration into `reduxPromiseWait`.
 *
 * @returns {Function} A http middleware function.
 */

exports.default = function (_ref4) {
  var rootComponent = _ref4.rootComponent;
  var createStore = _ref4.createStore;
  var renderRoot = _ref4.renderRoot;
  var mapState = _ref4.mapState;
  var mapAssets = _ref4.mapAssets;
  var _ref4$staticRender = _ref4.staticRender;
  var staticRender = _ref4$staticRender === undefined ? false : _ref4$staticRender;
  var _ref4$wait = _ref4.wait;
  var wait = _ref4$wait === undefined ? {} : _ref4$wait;

  var request = function request(req, res, store) {
    return store.dispatch((0, _action.httpRequest)(req));
  };
  var error = function error(err, req, res, store) {
    return store.dispatch((0, _action.httpError)(err, req));
  };

  var finalRenderRoot = renderRoot || createDefaultRenderRoot(staticRender, rootComponent);

  var render = createRenderHandler({
    mapState: mapState,
    mapAssets: mapAssets,
    renderRoot: function renderRoot() {
      return finalRenderRoot.apply(undefined, arguments);
    },
    wait: wait
  });

  return (0, _render2.default)({
    request: request,
    error: error,
    createStore: createStore,
    render: render
  });
};
//# sourceMappingURL=middleware.js.map